Changelog
=========

0.0.2 (2023-07-07)
------------------

- added support for supplying a password to use for the Redis connection (--password/--password_env)


0.0.1 (2021-09-22)
------------------

- initial release
